@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import com.openexchange.messaging.exception.MessagingExceptionFactory;
 
 /**
  * {@link MessagingExceptionCodes} - Enumeration of all {@link MessagingException}s.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since Open-Xchange v6.16
  */
@@ -144,7 +144,7 @@ public enum MessagingExceptionCodes implements OXErrorMessage {
     /**
      * Not connected
      */
-    NOT_CONNECTED(MessagingExceptionMessages.NOT_CONNECTED_MSG, Category.PERMISSION, 22), 
+    NOT_CONNECTED(MessagingExceptionMessages.NOT_CONNECTED_MSG, Category.PERMISSION, 22),
     /**
      * Invalid sorting column. Cannot sort by %1$s.
      */
@@ -152,7 +152,11 @@ public enum MessagingExceptionCodes implements OXErrorMessage {
     /**
      * No attachment found with section identifier %1$s in message %2$s in folder %3$s.
      */
-    ATTACHMENT_NOT_FOUND(MessagingExceptionMessages.ATTACHMENT_NOT_FOUND_MSG, Category.CODE_ERROR, 24);
+    ATTACHMENT_NOT_FOUND(MessagingExceptionMessages.ATTACHMENT_NOT_FOUND_MSG, Category.CODE_ERROR, 24),
+    /**
+     * Message %1$s not found in folder %2$s.
+     */
+    MESSAGE_NOT_FOUND(MessagingExceptionMessages.MESSAGE_NOT_FOUND_MSG, Category.CODE_ERROR, 25);
 
     private final Category category;
 
@@ -186,7 +190,7 @@ public enum MessagingExceptionCodes implements OXErrorMessage {
 
     /**
      * Creates a new messaging exception of this error type with no message arguments.
-     * 
+     *
      * @return A new twitter exception
      */
     public MessagingException create() {
@@ -195,7 +199,7 @@ public enum MessagingExceptionCodes implements OXErrorMessage {
 
     /**
      * Creates a new messaging exception of this error type with specified message arguments.
-     * 
+     *
      * @param messageArgs The message arguments
      * @return A new twitter exception
      */
@@ -205,7 +209,7 @@ public enum MessagingExceptionCodes implements OXErrorMessage {
 
     /**
      * Creates a new messaging exception of this error type with specified cause and message arguments.
-     * 
+     *
      * @param cause The cause
      * @param messageArgs The message arguments
      * @return A new twitter exception
