@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,7 @@ import java.util.Map;
 
 /**
  * {@link SimpleMessagingMessage}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class SimpleMessagingMessage implements MessagingMessage, MessagingBodyPart {
@@ -96,6 +96,8 @@ public class SimpleMessagingMessage implements MessagingMessage, MessagingBodyPa
 
     private String picture;
 
+    private String url;
+
     public int getColorLabel() {
         return colorLabel;
     }
@@ -188,14 +190,14 @@ public class SimpleMessagingMessage implements MessagingMessage, MessagingBodyPa
     public void setHeaders(final Map<String, Collection<MessagingHeader>> headers) {
         this.headers = headers;
     }
-    
-    public void putHeader(MessagingHeader header) {
+
+    public void putHeader(final MessagingHeader header) {
         if(headers.containsKey(header.getName())) {
             headers.get(header.getName()).add(header);
         } else {
             headers.put(header.getName(), new ArrayList<MessagingHeader>(Arrays.asList(header)));
         }
-        
+
     }
 
     public void setSectionId(final String sectionId) {
@@ -215,11 +217,11 @@ public class SimpleMessagingMessage implements MessagingMessage, MessagingBodyPa
     }
 
     public void setContent(final byte[] bytes) {
-        this.content = new ByteArrayContent(bytes);
+        content = new ByteArrayContent(bytes);
     }
 
     public void setContent(final MessagingBodyPart... parts) {
-        this.content = new MessagingPartArrayContent(parts);
+        content = new MessagingPartArrayContent(parts);
     }
 
     public MultipartContent getParent() throws MessagingException {
@@ -249,13 +251,21 @@ public class SimpleMessagingMessage implements MessagingMessage, MessagingBodyPa
     public String getPicture() {
         return picture;
     }
-    
-    public void setPicture(String picture) {
+
+    public void setPicture(final String picture) {
         this.picture = picture;
     }
 
-    public void setContentReference(String string) {
-      this.content =  new ReferenceContent(string);
+    public void setUrl(final String url) {
+        this.url = url;
+    }
+
+    public String getUrl() throws MessagingException {
+      return url;
+    }
+
+    public void setContentReference(final String string) {
+      content =  new ReferenceContent(string);
     }
 
 
